@@ -37,10 +37,11 @@ $( document ).ready(function() {
     var h = ["<ul>"];
     $.each(results, function(index, result) {
       h.push(
-        "<li><b>",
-        $("<div/>").text(result["name"]).html(),
-        "</b><br/>",
+        "<li>",
         $("<div/>").text(result["number"]).html(),
+        ": <b>",
+        $("<div/>").text(result["name"]).html(),
+        "</b>",
         "<p>",
         format(result["description"]),
         $.map(result["conversions"], function(value, key){
@@ -63,14 +64,31 @@ $( document ).ready(function() {
   function checkfield(field) {
     var value = field.val();
     // only trigger update if value changed from previous validation
-    if (value != $(this).data("oldvalue")) {
-      $(this).data("oldvalue", value);
-      $.get('', {number: value}, function(data) {
+    if (value != field.data("oldvalue")) {
+      field.data("oldvalue", value);
+      $.get('', {"number": value}, function(data) {
+        window.history.pushState({"value": value, "data": data}, $(document).find("title").text(), "?number=" + encodeURIComponent(value));
         updateresults(field, data);
       });
     }
   }
 
+  // update results based on history navigation
+  window.onpopstate = function(e) {
+    var field = $(".stdnum_check");
+    if (e.state) {
+      var value = e.state.value;
+      var data = e.state.data;
+      field.val(value)
+      field.data("oldvalue", value);
+      updateresults(field, data);
+    } else {
+      field.val("")
+      field.data("oldvalue", "");
+      updateresults(field, []);
+    }
+  };
+
   // trigger a check when user stopped typing
   $(".stdnum_check").on("input propertychange", function (event) {
       if (window.event && event.type == "propertychange" && event.propertyName != "value")
@@ -103,4 +121,11 @@ $( document ).ready(function() {
   // focus the text field
   $(".stdnum_check").focus();
 
+  // save current state
+  var value = $(".stdnum_check").val();
+  $(".stdnum_check").data("oldvalue", value);
+  $.get('', {number: value}, function(data) {
+    window.history.replaceState({"value": value, "data": data}, $(document).find("title").text(), "?number=" + encodeURIComponent(value));
+  })
+
 });
