@@ -59,8 +59,8 @@ def checksum(number):
 
 
 def validate(number):
-    """Checks to see if the number provided is a valid TFN. This checks the
-    length, formatting and check digit."""
+    """Check if the number is a valid TFN. This checks the length, formatting
+    and check digit."""
     number = compact(number)
     if not number.isdigit():
         raise InvalidFormat()
@@ -72,8 +72,7 @@ def validate(number):
 
 
 def is_valid(number):
-    """Checks to see if the number provided is a valid TFN. This checks the
-    length, formatting and check digit."""
+    """Check if the number is a valid TFN."""
     try:
         return bool(validate(number))
     except ValidationError:
@@ -81,6 +80,6 @@ def is_valid(number):
 
 
 def format(number):
-    """Reformat the passed number to the standard format."""
+    """Reformat the number to the standard presentation format."""
     number = compact(number)
     return ' '.join((number[0:3], number[3:6], number[6:]))
