@@ -1,7 +1,7 @@
 # egn.py - functions for handling Bulgarian national identification numbers
 # coding: utf-8
 #
-# Copyright (C) 2012, 2013 Arthur de Jong
+# Copyright (C) 2012-2015 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -57,7 +57,7 @@ def calc_check_digit(number):
     """Calculate the check digit. The number passed should not have the
     check digit included."""
     weights = (2, 4, 8, 5, 10, 9, 7, 3, 6)
-    return str(sum(weights[i] * int(n) for i, n in enumerate(number)) % 11 % 10)
+    return str(sum(w * int(n) for w, n in zip(weights, number)) % 11 % 10)
 
 
 def get_birth_date(number):
@@ -78,16 +78,15 @@ def get_birth_date(number):
 
 
 def validate(number):
-    """Checks to see if the number provided is a valid national
-    identification number. This checks the length, formatting, embedded
-    date and check digit."""
+    """Check if the number is a valid national identification number. This
+    checks the length, formatting, embedded date and check digit."""
     number = compact(number)
     if not number.isdigit():
         raise InvalidFormat()
     if len(number) != 10:
         raise InvalidLength()
     # check if birth date is valid
-    birth_date = get_birth_date(number)
+    get_birth_date(number)
     # TODO: check that the birth date is not in the future
     # check the check digit
     if calc_check_digit(number[:-1]) != number[-1]:
@@ -96,9 +95,7 @@ def validate(number):
 
 
 def is_valid(number):
-    """Checks to see if the number provided is a valid national
-    identification number. This checks the length, formatting, embedded
-    date and check digit."""
+    """Check if the number is a valid national identification number."""
     try:
         return bool(validate(number))
     except ValidationError:
