@@ -1,6 +1,6 @@
 # cvr.py - functions for handling Danish CVR numbers
 #
-# Copyright (C) 2012, 2013 Arthur de Jong
+# Copyright (C) 2012-2015 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -46,12 +46,12 @@ def compact(number):
 def checksum(number):
     """Calculate the checksum."""
     weights = (2, 7, 6, 5, 4, 3, 2, 1)
-    return sum(weights[i] * int(n) for i, n in enumerate(number)) % 11
+    return sum(w * int(n) for w, n in zip(weights, number)) % 11
 
 
 def validate(number):
-    """Checks to see if the number provided is a valid VAT number. This checks
-    the length, formatting and check digit."""
+    """Check if the number provided is a valid VAT number. This checks the
+    length, formatting and check digit."""
     number = compact(number)
     if not number.isdigit() or number[0] == '0':
         raise InvalidFormat()
@@ -63,8 +63,8 @@ def validate(number):
 
 
 def is_valid(number):
-    """Checks to see if the number provided is a valid VAT number. This checks
-    the length, formatting and check digit."""
+    """Check if the number provided is a valid VAT number. This checks the
+    length, formatting and check digit."""
     try:
         return bool(validate(number))
     except ValidationError:
