@@ -65,8 +65,8 @@ def calc_check_digits(number):
 
 
 def validate(number):
-    """Checks to see if the number provided is a valid DNI number. This
-    checks the length, formatting and check digit."""
+    """Check if the number provided is a valid DNI number. This checks the
+    length, formatting and check digit."""
     number = compact(number)
     if not number[1:-1].isdigit():
         raise InvalidFormat()
@@ -92,8 +92,8 @@ def validate(number):
 
 
 def is_valid(number):
-    """Checks to see if the number provided is a valid DNI number. This
-    checks the length, formatting and check digit."""
+    """Check if the number provided is a valid DNI number. This checks the
+    length, formatting and check digit."""
     try:
         return bool(validate(number))
     except ValidationError:
