@@ -59,7 +59,7 @@ _ibandb = numdb.get('iban')
 _struct_re = re.compile(r'([1-9][0-9]*)!([nac])')
 
 # cache of country codes to modules
-_country_modules = dict()
+_country_modules = {}
 
 
 def compact(number):
@@ -98,8 +98,8 @@ def _get_cc_module(cc):
 
 
 def validate(number, check_country=True):
-    """Checks to see if the number provided is a valid IBAN. The country-
-    specific check can be disabled with the check_country argument."""
+    """Check if the number provided is a valid IBAN. The country-specific
+    check can be disabled with the check_country argument."""
     number = compact(number)
     # ensure that checksum is valid
     mod_97_10.validate(number[4:] + number[:4])
@@ -119,7 +119,7 @@ def validate(number, check_country=True):
 
 
 def is_valid(number, check_country=True):
-    """Checks to see if the number provided is a valid IBAN."""
+    """Check if the number provided is a valid IBAN."""
     try:
         return bool(validate(number, check_country=check_country))
     except ValidationError:
@@ -129,7 +129,4 @@ def is_valid(number, check_country=True):
 def format(number, separator=' '):
     """Reformat the passed number to the space-separated format."""
     number = compact(number)
-    module = _get_cc_module(number[:2])
-    if module and hasattr(module, 'format') and module.format != format:
-        return module.format(number, separator=separator)
     return separator.join(number[i:i + 4] for i in range(0, len(number), 4))
