@@ -48,12 +48,13 @@ def compact(number):
 def calc_check_digit(number):
     """Calculate the check digit. The number passed should not have the
     check digit included."""
-    return str((11 - sum((9 - i) * int(n) for i, n in enumerate(number)) ) % 11 % 10)
+    s = sum((9 - i) * int(n) for i, n in enumerate(number))
+    return str((11 - s) % 11 % 10)
 
 
 def validate(number):
-    """Checks to see if the number provided is a valid VAT number. This
-    checks the length, formatting and check digit."""
+    """Check if the number is a valid VAT number. This checks the length,
+    formatting and check digit."""
     number = compact(number)
     if not number.isdigit() or number[0] == '0':
         raise InvalidFormat()
@@ -65,8 +66,7 @@ def validate(number):
 
 
 def is_valid(number):
-    """Checks to see if the number provided is a valid VAT number. This
-    checks the length, formatting and check digit."""
+    """Check if the number is a valid VAT number."""
     try:
         return bool(validate(number))
     except ValidationError:
