@@ -1,7 +1,7 @@
 # cnp.py - functions for handling Romanian CNP numbers
 # coding: utf-8
 #
-# Copyright (C) 2012, 2013 Arthur de Jong
+# Copyright (C) 2012-2015 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -56,7 +56,7 @@ def calc_check_digit(number):
     should not have the check digit included."""
     # note that this algorithm has not been confirmed by an independent source
     weights = (2, 7, 9, 1, 4, 6, 3, 5, 8, 2, 7, 9)
-    check = sum(weights[i] * int(n) for i, n in enumerate(number)) % 11
+    check = sum(w * int(n) for w, n in zip(weights, number)) % 11
     return '1' if check == 10 else str(check)
 
 
@@ -75,8 +75,8 @@ def get_birth_date(number):
 
 
 def validate(number):
-    """Checks to see if the number provided is a valid VAT number. This checks
-    the length, formatting and check digit."""
+    """Check if the number is a valid VAT number. This checks the length,
+    formatting and check digit."""
     number = compact(number)
     # first digit should be a known one (9=foreigner)
     if not number.isdigit() or number[0] not in '1234569':
@@ -84,7 +84,7 @@ def validate(number):
     if len(number) != 13:
         raise InvalidLength()
     # check if birth date is valid
-    birth_date = get_birth_date(number)
+    get_birth_date(number)
     # TODO: check that the birth date is not in the future
     # number[7:9] is the county, we ignore it for now, just check last digit
     if calc_check_digit(number[:-1]) != number[-1]:
@@ -93,8 +93,7 @@ def validate(number):
 
 
 def is_valid(number):
-    """Checks to see if the number provided is a valid VAT number. This checks
-    the length, formatting and check digit."""
+    """Check if the number is a valid VAT number."""
     try:
         return bool(validate(number))
     except ValidationError:
