@@ -49,5 +49,5 @@ InvalidLength: ...
 
 # since this number is essentially the same as the Czech counterpart
 # (until 1993 the Czech Republic and Slovakia were one country)
-from stdnum.cz.rc import compact, validate, is_valid, format
+from stdnum.cz.rc import compact, format, is_valid, validate
 __all__ = ['compact', 'validate', 'is_valid', 'format']
